==> kvirc-trinity_3.5.13.2.orig.tar.xz: kvirc-trinity-3.5.13.2/src/kvilib/tal/kvi_tal_mainwindow.cpp <==
//
//   File : kvi_tal_mainwindow.coo
//   Creation date : Sun Aug 12 2001 04:40:24 by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 2001 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
//

#define __KVILIB__


#include "kvi_tal_mainwindow.h"

#ifdef COMPILE_KDE_SUPPORT

	KviTalMainWindow::KviTalMainWindow(TQWidget * par,const char * nam)
	: KMainWindow(par,nam)
	{
	}

	#include "kvi_tal_mainwindow_kde.moc"

#else

	#ifdef COMPILE_USE_QT4
		KviTalMainWindow::KviTalMainWindow(TQWidget * par,const char * nam)
		: TQMainWindow(par,nam)
		{
		}

		bool KviTalMainWindow::usesBigPixmaps()
		{
			return (iconSize().width() > 40);
		}
		
		void KviTalMainWindow::setUsesBigPixmaps(bool b)
		{
			if(b)setIconSize(TQSize(48,48));
			else setIconSize(TQSize(24,24));
		}
		#include "kvi_tal_mainwindow_qt4.moc"
	#else
		KviTalMainWindow::KviTalMainWindow(TQWidget * par,const char * nam)
		: TQMainWindow(par,nam)
		{
		}
		#include "kvi_tal_mainwindow_qt3.moc"
	#endif

#endif

KviTalMainWindow::~KviTalMainWindow()
{
}

==> kvirc-trinity-14.0.11.tar.xz: kvirc-trinity-14.0.11/src/kvilib/tal/kvi_tal_mainwindow.cpp <==
//
//   File : kvi_tal_mainwindow.coo
//   Creation date : Sun Aug 12 2001 04:40:24 by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 2001 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
//

#define __KVILIB__


#include "kvi_tal_mainwindow.h"

#ifdef COMPILE_TDE_SUPPORT

	KviTalMainWindow::KviTalMainWindow(TQWidget * par,const char * nam)
	: TDEMainWindow(par,nam)
	{
	}

	#include "kvi_tal_mainwindow_kde.moc"

#else

	#ifdef COMPILE_USE_QT4
		KviTalMainWindow::KviTalMainWindow(TQWidget * par,const char * nam)
		: TQMainWindow(par,nam)
		{
		}

		bool KviTalMainWindow::usesBigPixmaps()
		{
			return (iconSize().width() > 40);
		}
		
		void KviTalMainWindow::setUsesBigPixmaps(bool b)
		{
			if(b)setIconSize(TQSize(48,48));
			else setIconSize(TQSize(24,24));
		}
		#include "kvi_tal_mainwindow_qt4.moc"
	#else
		KviTalMainWindow::KviTalMainWindow(TQWidget * par,const char * nam)
		: TQMainWindow(par,nam)
		{
		}
		#include "kvi_tal_mainwindow_qt3.moc"
	#endif

#endif

KviTalMainWindow::~KviTalMainWindow()
{
}
